@@ -28,7 +28,6 @@ import (
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/klog/v2"
-
 	"k8s.io/kops"
 	api "k8s.io/kops/pkg/apis/kops"
 	kopsapi "k8s.io/kops/pkg/apis/kops"
@@ -158,6 +157,8 @@ type NewClusterOptions struct {
 	Image       string
 	NodeImage   string
 	MasterImage string
+	MasterSize  string
+	NodeSize    string
 }
 
 func (o *NewClusterOptions) InitDefaults() {
@@ -248,6 +249,9 @@ func NewCluster(opt *NewClusterOptions, clientset simple.Clientset) (*NewCluster
 		cluster.Spec.SSHAccess = opt.AdminAccess
 	}
 
+	if len(opt.Zones) == 0 {
+		return nil, fmt.Errorf("must specify at least one zone for the cluster (use --zones)")
+	}
 	allZones := sets.NewString()
 	allZones.Insert(opt.Zones...)
 	allZones.Insert(opt.MasterZones...)
@@ -583,10 +587,6 @@ func setupZones(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.Stri
 	var err error
 	zoneToSubnetMap := make(map[string]*api.ClusterSubnetSpec)
 
-	if len(opt.Zones) == 0 {
-		return nil, fmt.Errorf("must specify at least one zone for the cluster (use --zones)")
-	}
-
 	var zoneToSubnetProviderID map[string]string
 
 	switch cluster.Spec.GetCloudProvider() {
@@ -858,6 +858,7 @@ func setupMasters(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap
 				}
 			}
 
+			g.Spec.MachineType = opt.MasterSize
 			g.Spec.Image = opt.MasterImage
 
 			masters = append(masters, g)
@@ -985,6 +986,7 @@ func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap ma
 			}
 		}
 
+		g.Spec.MachineType = opt.NodeSize
 		g.Spec.Image = opt.NodeImage
 
 		nodes = append(nodes, g)
@@ -1463,11 +1465,16 @@ func MachineArchitecture(cloud fi.Cloud, machineType string) (architectures.Arch
 		return architectures.ArchitectureAmd64, nil
 	}
 
+	// Some calls only have AWS initialised at this point and in other cases pass in nil as cloud.
+	if cloud == nil {
+		return architectures.ArchitectureAmd64, nil
+	}
+
 	switch cloud.ProviderID() {
 	case kopsapi.CloudProviderAWS:
 		info, err := cloud.(awsup.AWSCloud).DescribeInstanceType(machineType)
 		if err != nil {
-			return "", fmt.Errorf("error finding instance info for instance type %q: %v", machineType, err)
+			return "", fmt.Errorf("error finding instance info for instance type %q: %w", machineType, err)
 		}
 		if info.ProcessorInfo == nil || len(info.ProcessorInfo.SupportedArchitectures) == 0 {
 			return "", fmt.Errorf("error finding architecture info for instance type %q", machineType)
